Answer class

A single collected answer.

Constructors

Answer({required String questionId, required QuestionType type, required Object value})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
questionId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type QuestionType
final
value Object
int, String, or List<String>.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited