BrandColors class
A semantic colour palette; null on any token means "inherit the preset".
Constructors
- BrandColors({Color? primary, Color? background, Color? surface, Color? textPrimary, Color? textSecondary, Color? border})
-
const
-
BrandColors.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- background → Color?
-
final
- border → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- primary → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → Color?
-
final
- textPrimary → Color?
-
final
- textSecondary → Color?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited