InsitoEventPayload class

Payload delivered to an InsitoEventListener. Only the fields relevant to the fired event are populated.

Constructors

InsitoEventPayload({String? apiUrl, String? surveyId, String? responseId, int? queueLength, String? screenName, Map<String, int>? screens, String? reason, String? where, String? message})
const

Properties

apiUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
queueLength int?
final
reason String?
final
responseId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String?
final
screens Map<String, int>?
final
surveyId String?
final
where String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited