InsitoColors class
- Annotations
Constructors
- InsitoColors({required Color background, required Color surface, required Color overlay, required Color text, required Color textMuted, required Color border, required Color primary, required Color primaryText, required Color npsDetractor, required Color npsPassive, required Color npsPromoter})
-
const
Properties
- background → Color
-
final
- border → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- npsDetractor → Color
-
final
- npsPassive → Color
-
final
- npsPromoter → Color
-
final
- overlay → Color
-
final
- primary → Color
-
final
- primaryText → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → Color
-
final
- text → Color
-
final
- textMuted → Color
-
final
Methods
-
merge(
InsitoColorsOverride? o) → InsitoColors -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited